@@ -26,8 +26,10 @@ from .literals import (
 )
 from .paginator import ListServersPaginator
 from .type_defs import (
+    CreateAccessResponseTypeDef,
     CreateServerResponseTypeDef,
     CreateUserResponseTypeDef,
+    DescribeAccessResponseTypeDef,
     DescribeSecurityPolicyResponseTypeDef,
     DescribeServerResponseTypeDef,
     DescribeUserResponseTypeDef,
@@ -35,6 +37,7 @@ from .type_defs import (
     HomeDirectoryMapEntryTypeDef,
     IdentityProviderDetailsTypeDef,
     ImportSshPublicKeyResponseTypeDef,
+    ListAccessesResponseTypeDef,
     ListSecurityPoliciesResponseTypeDef,
     ListServersResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
@@ -42,6 +45,7 @@ from .type_defs import (
     PosixProfileTypeDef,
     TagTypeDef,
     TestIdentityProviderResponseTypeDef,
+    UpdateAccessResponseTypeDef,
     UpdateServerResponseTypeDef,
     UpdateUserResponseTypeDef,
 )
@@ -78,7 +82,7 @@ class Exceptions:
 
 class TransferClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -87,10 +91,26 @@ class TransferClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.can_paginate)
         [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
+    def create_access(
+        self,
+        Role: str,
+        ServerId: str,
+        ExternalId: str,
+        HomeDirectory: str = None,
+        HomeDirectoryType: HomeDirectoryTypeType = None,
+        HomeDirectoryMappings: List["HomeDirectoryMapEntryTypeDef"] = None,
+        Policy: str = None,
+        PosixProfile: "PosixProfileTypeDef" = None,
+    ) -> CreateAccessResponseTypeDef:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.create_access)
+        [Show boto3-stubs documentation](./client.md#create_access)
+        """
+
     def create_server(
         self,
         Certificate: str = None,
@@ -106,7 +126,7 @@ class TransferClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateServerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.create_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.create_server)
         [Show boto3-stubs documentation](./client.md#create_server)
         """
 
@@ -124,45 +144,57 @@ class TransferClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateUserResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.create_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.create_user)
         [Show boto3-stubs documentation](./client.md#create_user)
         """
 
+    def delete_access(self, ServerId: str, ExternalId: str) -> None:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.delete_access)
+        [Show boto3-stubs documentation](./client.md#delete_access)
+        """
+
     def delete_server(self, ServerId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.delete_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.delete_server)
         [Show boto3-stubs documentation](./client.md#delete_server)
         """
 
     def delete_ssh_public_key(self, ServerId: str, SshPublicKeyId: str, UserName: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.delete_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.delete_ssh_public_key)
         [Show boto3-stubs documentation](./client.md#delete_ssh_public_key)
         """
 
     def delete_user(self, ServerId: str, UserName: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.delete_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.delete_user)
         [Show boto3-stubs documentation](./client.md#delete_user)
         """
 
+    def describe_access(self, ServerId: str, ExternalId: str) -> DescribeAccessResponseTypeDef:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.describe_access)
+        [Show boto3-stubs documentation](./client.md#describe_access)
+        """
+
     def describe_security_policy(
         self, SecurityPolicyName: str
     ) -> DescribeSecurityPolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.describe_security_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.describe_security_policy)
         [Show boto3-stubs documentation](./client.md#describe_security_policy)
         """
 
     def describe_server(self, ServerId: str) -> DescribeServerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.describe_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.describe_server)
         [Show boto3-stubs documentation](./client.md#describe_server)
         """
 
     def describe_user(self, ServerId: str, UserName: str) -> DescribeUserResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.describe_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.describe_user)
         [Show boto3-stubs documentation](./client.md#describe_user)
         """
 
@@ -174,7 +206,7 @@ class TransferClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
@@ -182,15 +214,23 @@ class TransferClient:
         self, ServerId: str, SshPublicKeyBody: str, UserName: str
     ) -> ImportSshPublicKeyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.import_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.import_ssh_public_key)
         [Show boto3-stubs documentation](./client.md#import_ssh_public_key)
         """
 
+    def list_accesses(
+        self, ServerId: str, MaxResults: int = None, NextToken: str = None
+    ) -> ListAccessesResponseTypeDef:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.list_accesses)
+        [Show boto3-stubs documentation](./client.md#list_accesses)
+        """
+
     def list_security_policies(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListSecurityPoliciesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.list_security_policies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.list_security_policies)
         [Show boto3-stubs documentation](./client.md#list_security_policies)
         """
 
@@ -198,7 +238,7 @@ class TransferClient:
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListServersResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.list_servers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.list_servers)
         [Show boto3-stubs documentation](./client.md#list_servers)
         """
 
@@ -206,7 +246,7 @@ class TransferClient:
         self, Arn: str, MaxResults: int = None, NextToken: str = None
     ) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
@@ -214,25 +254,25 @@ class TransferClient:
         self, ServerId: str, MaxResults: int = None, NextToken: str = None
     ) -> ListUsersResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.list_users)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.list_users)
         [Show boto3-stubs documentation](./client.md#list_users)
         """
 
     def start_server(self, ServerId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.start_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.start_server)
         [Show boto3-stubs documentation](./client.md#start_server)
         """
 
     def stop_server(self, ServerId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.stop_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.stop_server)
         [Show boto3-stubs documentation](./client.md#stop_server)
         """
 
     def tag_resource(self, Arn: str, Tags: List["TagTypeDef"]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.tag_resource)
         [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
@@ -245,16 +285,32 @@ class TransferClient:
         UserPassword: str = None,
     ) -> TestIdentityProviderResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.test_identity_provider)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.test_identity_provider)
         [Show boto3-stubs documentation](./client.md#test_identity_provider)
         """
 
     def untag_resource(self, Arn: str, TagKeys: List[str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.untag_resource)
         [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
+    def update_access(
+        self,
+        ServerId: str,
+        ExternalId: str,
+        HomeDirectory: str = None,
+        HomeDirectoryType: HomeDirectoryTypeType = None,
+        HomeDirectoryMappings: List["HomeDirectoryMapEntryTypeDef"] = None,
+        Policy: str = None,
+        PosixProfile: "PosixProfileTypeDef" = None,
+        Role: str = None,
+    ) -> UpdateAccessResponseTypeDef:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.update_access)
+        [Show boto3-stubs documentation](./client.md#update_access)
+        """
+
     def update_server(
         self,
         ServerId: str,
@@ -268,7 +324,7 @@ class TransferClient:
         SecurityPolicyName: str = None,
     ) -> UpdateServerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.update_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.update_server)
         [Show boto3-stubs documentation](./client.md#update_server)
         """
 
@@ -284,11 +340,11 @@ class TransferClient:
         Role: str = None,
     ) -> UpdateUserResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Client.update_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Client.update_user)
         [Show boto3-stubs documentation](./client.md#update_user)
         """
 
     def get_paginator(self, operation_name: Literal["list_servers"]) -> ListServersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/transfer.html#Transfer.Paginator.ListServers)[Show boto3-stubs documentation](./paginators.md#listserverspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/transfer.html#Transfer.Paginator.ListServers)[Show boto3-stubs documentation](./paginators.md#listserverspaginator)
         """
